import React, { useState, useEffect } from 'react';
import { Input, Button, Card, Form,  notification } from 'antd';
import router from 'umi/router';
// import Styles from './style.less';
import ImageUploader from '../../../components/XForm/ImageUpload';
import request from '../../../utils/request';
import apis from '../../../services/apis';

const formItemLayout = {
    labelCol: {
      xs: { span: 24 },
      sm: { span: 8 },
    },
    wrapperCol: {
      xs: { span: 24 },
      sm: { span: 16 },
    },
  };
  const tailFormItemLayout = {
    wrapperCol: {
      xs: {
        span: 24,
        offset: 0,
      },
      sm: {
        span: 16,
        offset: 8,
      },
    },
  };

function Edit(props) {
  const { getFieldDecorator } = props.form;

  // eslint-disable-next-line react-hooks/rules-of-hooks
  let data = {};
  const { id } = props.location.query;

  useEffect(() => {
    if (id) {
      getById(id);
    }
  }, [id]);

  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        // 提交数据
        submitData(values);
      }
    });
  }

  // 获取详情信息
  function getById(currentId) {
    request({ ...apis.buildingType.getById, urlData: { id: currentId } }).then(res => {
      data = res;
      props.form.setFieldsValue(res);
    });
  }

  const openNotificationWithIcon = (type, message) => {
    notification[type]({
      message,
      description: '',
    });
  };

  function submitData(dataSources) {
    if (id !== '') {
      // 修改
      updateType(dataSources);
      return;
    }

    dataSources.status = 1;
    dataSources.createDate = new Date();
    request({ ...apis.buildingType.add, data: { ...dataSources } })
      .then(() => {
        // eslint-disable-next-line no-unused-expressions
        openNotificationWithIcon('success', '操作成功');
        router.go(-1);
      })
      .catch(err => {});
  }

  // 修改
  function updateType(row) {
    // const { url, method } = apis.buildingType.update
    // const tempUrl = url.substring(0, url.lastIndexOf('id')).concat(row.buildingTypeId)

    // request({ url: tempUrl, method, data: { ...row } }).then(() => {
    //   router.go(-1)
    // })
    request({ ...apis.buildingType.update, urlData: { id: row.buildingTypeId }, data: { ...row } })
      .then(() => {
        // eslint-disable-next-line no-unused-expressions
        openNotificationWithIcon('success', '操作成功');
        router.go(-1);
      })
      .catch(err => {});
  }

  return (
    <Card>
      <Form {...formItemLayout} onSubmit={handleSubmit}>
      <Form.Item label="开发商名称">
          {getFieldDecorator('name', {
            rules: [
              {
                required: true,
                message: '请输入开发商名称!',
              },
            ],
          })(<Input style={{width:200}}/>)}
        </Form.Item>
        <Form.Item label="开发商索引">
          {getFieldDecorator('ind', {
            rules: [{ required: true, message: '请输入开发商索引' }],
          })(<Input style={{width:200}}/>)}
        </Form.Item>
        <Form.Item label="品牌宣传图">
          {getFieldDecorator('img', {
            rules: [{ required: true, message: '请上传品牌宣传图' }],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="开发商简介">
          {getFieldDecorator('buildingTypeName', {
            rules: [{ required: true, message: '请输入开发商简介' }],
          })(<Input.TextArea style={{width:400}} placeholder="120字内的简介"/>)}
        </Form.Item>
       
        <Form.Item  {...tailFormItemLayout} style={{ display: 'flex', justifyContent: 'space-between' }}>
          <Button type="primary" htmlType="submit" style={{ margin: '0' }}>
            确定
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => router.go(-1)}>取消</Button>
        </Form.Item>
      </Form>
    </Card>
  );
}

const WrappedBuidingTypeForm = Form.create({ name: 'Edit' })(Edit);

export default WrappedBuidingTypeForm;
