import React from 'react'
import { Form, Input, notification, Select } from 'antd'
import FileUpload from '@/components/XForm/FileUpload';
import BuildingType from './components/BuildingTypeSelect'
import { formItemLayout } from './utils'

const Item = Form.Item

const BuildingBasic = (props) => {
  const { form } = props;
  const { getFieldDecorator } = form;

  
  // 视频文件上传前 回调
  const fileUploadBeforeUpload = (file, fileList) => {
    return new Promise((resolve, reject) => {
      if (file.type === 'video/mp4' || file.type === '.mp4') {
          // setVideoImage(true)
          resolve(file)
      } else {
        notification.error({ message: '项目视频，仅支持MP4格式' })
        reject()
      }
    })
  }

  return (
    <Form {...formItemLayout}>
      <Item label="项目Id" style={{ display: 'none' }}>
        {getFieldDecorator('buildingId')(<Input disabled />)}
      </Item>
      <Item label="楼盘编号" >
        {getFieldDecorator('code', {
          rules: [{ required: true, message: '请输入楼盘编号' }],
        })(<Input />)}
      </Item>
      <Item label="楼盘名称" >
        {getFieldDecorator('buildingName', {
          rules: [{ required: true, message: '请输入楼盘名' }],
        })(<Input />)}
      </Item>
      <Form.Item label="项目类型">
        {getFieldDecorator('buildingProjectType', {
          rules: [{ required: true, message: '请选择项目类型' }],
        })(<BuildingType />)}
      </Form.Item>
      <Form.Item label="列表均价" help="项目列表展示价格，示例：约10000元/㎡、约1000万元/套起">
        {getFieldDecorator('price')(<Input />)}
      </Form.Item>
      <Form.Item label="开盘时间" >
        {getFieldDecorator('openingDate')(<Input placeholder="预计xxxx年xx月开盘" />)}
      </Form.Item>
      <Form.Item label="电话" >
        {getFieldDecorator('tel', {
          rules: [
            {
              pattern: new RegExp('^[0-9]*$'),
              message: '请输入正确的电话号码',
            },
          ],
        })(<Input placeholder="手机或者座机号码" />)}
      </Form.Item>
      <Form.Item label="项目说明" >
        {getFieldDecorator('dynamic')(<Input placeholder="项目动态等，不超过30个字" maxLength={30}/>)}
      </Form.Item>
      <Form.Item label="物业类型" >
        {getFieldDecorator('propertyType')(<Input />)}
      </Form.Item>
      <Form.Item label="销售状态" >
        {getFieldDecorator('marketStatus', {
          rules: [{ required: true, message: '请选择销售状态' }],
        })(
          <Select placeholder="销售状态" style={{ width: '100%' }}>
            <Select.Option value="待售">待售</Select.Option>
            <Select.Option value="在售">在售</Select.Option>
            <Select.Option value="售罄">售罄</Select.Option>
            <Select.Option value="在租">在租</Select.Option>
          </Select>,
        )}
      </Form.Item>
      <Form.Item label="项目标签" >
        {getFieldDecorator('tag')(
          <Select mode="tags" placeholder="输入后选中" style={{ width: '100%' }} />
        )}
      </Form.Item>
      <Form.Item label="项目视频" help="视频仅支持mp4格式，建议尺寸：750*600，比例5:4，用于楼盘详情">
        {getFieldDecorator('videoUrl')(
          <FileUpload accept=".mp4" beforeUpload={fileUploadBeforeUpload} label="上传视频" size={1} />,
        )}
      </Form.Item>

    </Form>
  )
}

export default Form.create({ onValuesChange: console.log })(BuildingBasic)
