import React, { useState, useEffect } from 'react';
import { Form, Select, Modal, Button, Table, Divider, Tag, Input } from 'antd';
import { apis, fetch } from '../../utils/request';
import Navigate from '@/components/Navigate';

const { Search } = Input;

const getGroupList = fetch(apis.taliveActivity.taLiveActivity)

export default props => {
  const {
    value,
    onChange,
    ...rest
  } = props;

  const [list, setList] = useState([]);
  const [visible, setVisible] = useState(false);
  const [group, setGroup] = useState({ groupId: undefined, groupName: '请选择直播活动' })
  const getGroupTitle = val => {
    return (list.filter(x => x.liveActivityId == val)[0] || {}).liveActivityTitle || '请选择直播活动'
  }
  const updateGroup = val => setGroup({ groupId: val, groupName: getGroupTitle(val) })

  const buildingId = props.buildingId()

  useEffect(() => {
    getGroupList({
      params: {
        buildingId,
        pageNum: 1,
        pageSize: 999,
        status: 1,
        source: 2,
      },
    }).then(data => {
      setList(data.records || [])

       const getGroupTitle = val => {
        return (data.records.filter(x => x.liveActivityId == val)[0] || {}).liveActivityTitle || '请选择直播活动'
      }
      const updateGroup = val => setGroup({ groupId: val, groupName: getGroupTitle(val) })

      updateGroup(buildingId ? undefined : value);

      // updateGroup(buildingId ? undefined : value);
    })
  }, [buildingId]);
  const searchGroup = (e) => {
    getGroupList({
      params: {
        buildingId,
        pageNum: 1,
        pageSize: 999,
        status: 1,
        source: 2,
        liveActivityTitle: e
      }
    }).then((data) => {
      setList(data.records || [])

      // const getGroupTitle = val => {
      //   return (data.records.filter(x => x.liveActivityId == val)[0] || {}).liveActivityTitle || '请选择直播活动'
      // }
      // const updateGroup = val => setGroup({ groupId: val, groupName: getGroupTitle(val) })

      updateGroup(buildingId ? undefined : value);
      // setAct(buildingId ? undefined : value);
    })
  }
  if (value !== group.groupId) {
    updateGroup(value);
  }

  const handleChange = val => {
    onChange(val)
  }

  const setData = val => {
    updateGroup(val)
    onChange(val)
    setVisible(false)
  }

  const columns = [
    {
      title: '标题',
      dataIndex: 'liveActivityTitle',
      key: 'liveActivityId',
      align: 'center',
      ellipsis: true,
      render: text => <a>{text}</a>,
    },
    {
      title: '操作',
      align: 'center',
      width: '20%',
      render: (text, record) => (
        <Navigate onClick={() => setData(record.liveActivityId)}>选择</Navigate>
      ),
    },
  ];

  return (
    <div>
             <div ><Navigate onClick={() => setVisible(true)}>{group.groupName}</Navigate></div>
      <Modal
        title="请选择"
        visible={visible}
        onCancel={() => setVisible(false)}
        footer={[]}
      >
        <Search
          placeholder="请输入标题"
          enterButton="搜索"
          size="large"
          onSearch={value => searchGroup(value)}
          style={{ marginBottom: '16px' }}
        />
        <Table rowKey={list => list.liveActivityId} columns={columns} dataSource={list} />
      </Modal>
    </div>
  );
}
